@@ -1,6 +1,6 @@
 # -*- coding: utf-8; tab-width: 4; indent-tabs-mode: nil; -*-
 ### BEGIN LICENSE
-# Copyright (C) 2010 Kevin Mehall <km@kevinmehall.net>
+# Copyright (C) 2010-2012 Kevin Mehall <km@kevinmehall.net>
 #This program is free software: you can redistribute it and/or modify it 
 #under the terms of the GNU General Public License version 3, as published 
 #by the Free Software Foundation.
@@ -38,7 +38,7 @@ class MediaKeyPlugin(PithosPlugin):
     def mediakey_pressed(self, app, action):
        if app == APP_ID:
             if action == 'Play':
-                self.window.playpause()
+                self.window.playpause_notify()
             elif action == 'Next':
                 self.window.next_song()
             elif action == 'Stop':
